==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/el.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Ο διαμοιρασμός μεταξύ διακομιστών δεν έχει ενεργοποιηθεί σε αυτόν το διακομιστή",
    "The mountpoint name contains invalid characters." : "Το όνομα σημείου προσάρτησης περιέχει μη έγκυρους χαρακτήρες.",
    "Invalid or untrusted SSL certificate" : "Μη έγκυρο ή μη έμπιστο πιστοποιητικό SSL",
    "Could not authenticate to remote share, password might be wrong" : "Δεν ήταν δυνατή η πιστοποίηση στο απομακρυσμένο διαμοιρασμένο στοιχείο, μπορεί να είναι λάθος ο κωδικός πρόσβασης",
    "Storage not valid" : "Μη έγκυρος αποθηκευτικός χώρος",
    "Couldn't add remote share" : "Αδυναμία προσθήκης απομακρυσμένου κοινόχρηστου φακέλου",
    "Shared with you" : "Διαμοιρασμένο με εσάς",
    "Shared with others" : "Διαμοιρασμένο με άλλους",
    "Shared by link" : "Διαμοιρασμένο μέσω συνδέσμου",
    "Nothing shared with you yet" : "Κανένα αρχείο δεν έχει διαμοιραστεί ακόμα με εσάς.",
    "Files and folders others share with you will show up here" : "Τα αρχεία και οι φάκελοι που άλλοι διαμοιράζονται με εσάς θα εμφανιστούν εδώ",
    "Nothing shared yet" : "Δεν έχει διαμοιραστεί τίποτα μέχρι στιγμής",
    "Files and folders you share will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε θα εμφανιστούν εδώ",
    "No shared links" : "Κανένας διαμοιρασμένος σύνδεσμος",
    "Files and folders you share by link will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε μέσω συνδέσμου θα εμφανιστούνε εδώ",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Θέλετε να προσθέσουμε τον απομακρυσμένο κοινόχρηστο φάκελο {name} από {owner}@{remote}?",
    "Remote share" : "Απομακρυσμένος κοινόχρηστος φάκελος",
    "Remote share password" : "Κωδικός πρόσβασης απομακρυσμένου κοινόχρηστου φακέλου",
    "Cancel" : "Άκυρο",
    "Add remote share" : "Προσθήκη απομακρυσμένου κοινόχρηστου φακέλου",
    "You can upload into this folder" : "Μπορείτε να μεταφορτώσετε σε αυτόν τον φάκελο",
    "No ownCloud installation (7 or higher) found at {remote}" : "Δεν βρέθηκε εγκατάστση ownCloud (7 ή νεώτερη) στο {remote}",
    "Invalid ownCloud url" : "Άκυρη url ownCloud ",
    "Shared by" : "Διαμοιράστηκε από",
    "Sharing" : "Διαμοιρασμός",
    "A file or folder has been <strong>shared</strong>" : "Ένα αρχείο ή φάκελος <strong>διαμοιράστηκε</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Ένα αρχείο ή φάκελος διαμοιράστηκε από <strong>έναν άλλο διακομιστή</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Ένα δημόσια διαμοιρασμένο αρχείο ή φάκελος <strong>ελήφθη</strong>",
    "You received a new remote share %2$s from %1$s" : "Λάβατε ένα νέο απομακρυσμένο διαμοιρασμό %2$s από %1$s",
    "You received a new remote share from %s" : "Λάβατε ένα νέο απομακρυσμένο κοινόχρηστο φάκελο από %s",
    "%1$s accepted remote share %2$s" : "Ο %1$s αποδέχθηκε τον απομακρυσμένο φάκελο %2$s",
    "%1$s declined remote share %2$s" : "Ο %1$s αρνήθηκε τον απομακρυσμένο διαμοιρασμένο φάκελο %2$s",
    "%1$s unshared %2$s from you" : "Ο %1$s απέσυρε το διαμοιρασμό του %2$s με εσάς",
    "Public shared folder %1$s was downloaded" : "Ο κοινόχρηστος διαμοιρασμένος φάκελος %1$s ελήφθη",
    "Public shared file %1$s was downloaded" : "Το κοινόχρηστο διαμοιρασμένο αρχείο %1$s ελήφθη",
    "You shared %1$s with %2$s" : "Διαμοιραστήκατε το %1$s με %2$s",
    "You shared %1$s with group %2$s" : "Διαμοιραστήκατε %1$s με την ομάδα %2$s",
    "%2$s shared %1$s with %3$s" : "Ο %2$s διαμοιράστηκε το %1$s με %3$s",
    "%2$s shared %1$s with group %3$s" : "Ο %2$s διαμοιράστηκε το %1$s με την ομάδα %3$s",
    "%2$s shared %1$s via link" : "Ο %2$s διαμοιράστηκε το %1$s μέσω συνδέσμου",
    "%2$s shared %1$s with you" : "Ο %2$s διαμοιράστηκε το %1$s με εσάς",
    "You shared %1$s via link" : "Μοιραστήκατε το %1$s μέσω συνδέσμου",
    "Downloaded via public link" : "Μεταφορτώθηκε μέσω δημόσιου συνδέσμου",
    "Shared with %2$s" : "Διαμοιράστηκε με %2$s",
    "Shared with group %2$s" : "Διαμοιράστηκε με την ομάδα %2$s",
    "Shared with %3$s by %2$s" : "Διαμοιράστηκε με %3$s από %2$s",
    "Shared with group %3$s by %2$s" : "Διαμοιράστηκε με την ομάδα %3$s από %2$s",
    "Shared via link by %2$s" : "Διαμοιράστηκε μέσω συνδέσμου από %2$s",
    "Shared by %2$s" : "Διαμοιράστηκε από %2$s",
    "Shared via public link" : "Διαμοιράστηκε μέσω δημόσιου συνδέσμου",
    "Shares" : "Κοινόχρηστοι φάκελοι",
    "You received %2$s as a remote share from %1$s" : "Λάβατε το %2$s ως απομακρυσμένο διαμοιρασμό από %1$s",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Διαμοιρασμός με εμένα μέσω του #ownCloud Federated Cloud ID μου, δείτε %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Διαμοιρασμός με εμένα μέσω του #ownCloud Federated Cloud ID μου",
    "This share is password-protected" : "Αυτός ο κοινόχρηστος φάκελος προστατεύεται με κωδικό",
    "The password is wrong. Try again." : "Εσφαλμένος κωδικός πρόσβασης. Προσπαθήστε ξανά.",
    "Password" : "Κωδικός πρόσβασης",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Name" : "Όνομα",
    "Share time" : "Χρόνος διαμοιρασμού",
    "Sorry, this link doesn’t seem to work anymore." : "Συγγνώμη, αυτός ο σύνδεσμος μοιάζει να μην ισχύει πια.",
    "Reasons might be:" : "Οι λόγοι μπορεί να είναι:",
    "the item was removed" : "το αντικείμενο απομακρύνθηκε",
    "the link expired" : "ο σύνδεσμος έληξε",
    "sharing is disabled" : "ο διαμοιρασμός απενεργοποιήθηκε",
    "For more info, please ask the person who sent this link." : "Για περισσότερες πληροφορίες, παρακαλώ ρωτήστε το άτομο που σας έστειλε αυτόν τον σύνδεσμο.",
    "Add to your ownCloud" : "Προσθήκη στο ownCloud σου",
    "Download" : "Λήψη",
    "Download %s" : "Λήψη %s",
    "Direct link" : "Άμεσος σύνδεσμος",
    "Federated Cloud Sharing" : "Διαμοιρασμός σε ομόσπονδα σύννεφα ",
    "Open documentation" : "Ανοιχτή τεκμηρίωση.",
    "Allow users on this server to send shares to other servers" : "Να επιτρέπεται σε χρήστες αυτού του διακομιστή να στέλνουν διαμοιρασμένους φακέλους σε άλλους διακομιστές",
    "Allow users on this server to receive shares from other servers" : "Να επιτρέπεται στους χρίστες του διακομιστή να λαμβάνουν διαμοιρασμένα αρχεία από άλλους διακομιστές",
    "Federated Cloud" : "Federated σύννεφο",
    "Your Federated Cloud ID:" : "Το ID σας στο Federated Cloud:",
    "Share it:" : "Μοιραστείτε το:",
    "Add to your website" : "Προσθήκη στην ιστοσελίδα σας",
    "Share with me via ownCloud" : "Διαμοιρασμός με εμένα μέσω του ",
    "HTML Code:" : "Κώδικας HTML:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/el.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Ο διαμοιρασμός μεταξύ διακομιστών δεν έχει ενεργοποιηθεί σε αυτόν το διακομιστή",
    "The mountpoint name contains invalid characters." : "Το όνομα σημείου προσάρτησης περιέχει μη έγκυρους χαρακτήρες.",
    "Invalid or untrusted SSL certificate" : "Μη έγκυρο ή μη έμπιστο πιστοποιητικό SSL",
    "Could not authenticate to remote share, password might be wrong" : "Δεν ήταν δυνατή η πιστοποίηση στο απομακρυσμένο διαμοιρασμένο στοιχείο, μπορεί να είναι λάθος ο κωδικός πρόσβασης",
    "Storage not valid" : "Μη έγκυρος αποθηκευτικός χώρος",
    "Couldn't add remote share" : "Αδυναμία προσθήκης απομακρυσμένου κοινόχρηστου φακέλου",
    "Shared with you" : "Διαμοιρασμένα με εσάς",
    "Shared with others" : "Διαμοιρασμένα με άλλους",
    "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
    "Nothing shared with you yet" : "Κανένα αρχείο δεν έχει διαμοιραστεί ακόμα με εσάς.",
    "Files and folders others share with you will show up here" : "Τα αρχεία και οι φάκελοι που άλλοι διαμοιράζονται με εσάς θα εμφανιστούν εδώ",
    "Nothing shared yet" : "Δεν έχει διαμοιραστεί τίποτα μέχρι στιγμής",
    "Files and folders you share will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε θα εμφανιστούν εδώ",
    "No shared links" : "Κανένας διαμοιρασμένος σύνδεσμος",
    "Files and folders you share by link will show up here" : "Τα αρχεία και οι φάκελοι που διαμοιράζεστε μέσω συνδέσμου θα εμφανιστούνε εδώ",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Θέλετε να προσθέσουμε τον απομακρυσμένο κοινόχρηστο φάκελο {name} από {owner}@{remote}?",
    "Remote share" : "Απομακρυσμένος κοινόχρηστος φάκελος",
    "Remote share password" : "Κωδικός πρόσβασης απομακρυσμένου κοινόχρηστου φακέλου",
    "Cancel" : "Άκυρο",
    "Add remote share" : "Προσθήκη απομακρυσμένου κοινόχρηστου φακέλου",
    "You can upload into this folder" : "Μπορείτε να μεταφορτώσετε σε αυτόν τον φάκελο",
    "No ownCloud installation (7 or higher) found at {remote}" : "Δεν βρέθηκε εγκατάστση ownCloud (7 ή νεώτερη) στο {remote}",
    "Invalid ownCloud url" : "Άκυρη url ownCloud ",
    "Shared by" : "Διαμοιράστηκε από",
    "Sharing" : "Διαμοιρασμός",
    "A file or folder has been <strong>shared</strong>" : "Ένα αρχείο ή φάκελος <strong>διαμοιράστηκε</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Ένα αρχείο ή φάκελος διαμοιράστηκε από <strong>έναν άλλο διακομιστή</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Ένα δημόσια διαμοιρασμένο αρχείο ή φάκελος <strong>ελήφθη</strong>",
    "You received a new remote share %2$s from %1$s" : "Λάβατε ένα νέο απομακρυσμένο διαμοιρασμό %2$s από %1$s",
    "You received a new remote share from %s" : "Λάβατε ένα νέο απομακρυσμένο κοινόχρηστο φάκελο από %s",
    "%1$s accepted remote share %2$s" : "Ο %1$s αποδέχθηκε τον απομακρυσμένο φάκελο %2$s",
    "%1$s declined remote share %2$s" : "Ο %1$s αρνήθηκε τον απομακρυσμένο διαμοιρασμένο φάκελο %2$s",
    "%1$s unshared %2$s from you" : "Ο %1$s απέσυρε το διαμοιρασμό του %2$s με εσάς",
    "Public shared folder %1$s was downloaded" : "Ο κοινόχρηστος διαμοιρασμένος φάκελος %1$s ελήφθη",
    "Public shared file %1$s was downloaded" : "Το κοινόχρηστο διαμοιρασμένο αρχείο %1$s ελήφθη",
    "You shared %1$s with %2$s" : "Διαμοιραστήκατε το %1$s με %2$s",
    "%2$s shared %1$s with %3$s" : "Ο %2$s διαμοιράστηκε το %1$s με %3$s",
    "You shared %1$s with group %2$s" : "Διαμοιραστήκατε %1$s με την ομάδα %2$s",
    "%2$s shared %1$s with group %3$s" : "Ο %2$s διαμοιράστηκε το %1$s με την ομάδα %3$s",
    "%2$s shared %1$s via link" : "Ο %2$s διαμοιράστηκε το %1$s μέσω συνδέσμου",
    "You shared %1$s via link" : "Μοιραστήκατε το %1$s μέσω συνδέσμου",
    "%2$s shared %1$s with you" : "Ο %2$s διαμοιράστηκε το %1$s με εσάς",
    "Downloaded via public link" : "Μεταφορτώθηκε μέσω δημόσιου συνδέσμου",
    "Shared with %2$s" : "Διαμοιράστηκε με %2$s",
    "Shared with %3$s by %2$s" : "Διαμοιράστηκε με %3$s από %2$s",
    "Shared with group %2$s" : "Διαμοιράστηκε με την ομάδα %2$s",
    "Shared with group %3$s by %2$s" : "Διαμοιράστηκε με την ομάδα %3$s από %2$s",
    "Shared via link by %2$s" : "Διαμοιράστηκε μέσω συνδέσμου από %2$s",
    "Shared via public link" : "Διαμοιράστηκε μέσω δημόσιου συνδέσμου",
    "Shared by %2$s" : "Διαμοιράστηκε από %2$s",
    "Shares" : "Κοινόχρηστοι φάκελοι",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Διαμοιρασμός με εμένα μέσω του #ownCloud Federated Cloud ID μου, δείτε %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Διαμοιρασμός με εμένα μέσω του #ownCloud Federated Cloud ID μου",
    "This share is password-protected" : "Αυτός ο κοινόχρηστος φάκελος προστατεύεται με κωδικό",
    "The password is wrong. Try again." : "Εσφαλμένος κωδικός πρόσβασης. Προσπαθήστε ξανά.",
    "Password" : "Κωδικός πρόσβασης",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Name" : "Όνομα",
    "Share time" : "Χρόνος διαμοιρασμού",
    "Sorry, this link doesn’t seem to work anymore." : "Συγγνώμη, αυτός ο σύνδεσμος μοιάζει να μην ισχύει πια.",
    "Reasons might be:" : "Οι λόγοι μπορεί να είναι:",
    "the item was removed" : "το αντικείμενο απομακρύνθηκε",
    "the link expired" : "ο σύνδεσμος έληξε",
    "sharing is disabled" : "ο διαμοιρασμός απενεργοποιήθηκε",
    "For more info, please ask the person who sent this link." : "Για περισσότερες πληροφορίες, παρακαλώ ρωτήστε το άτομο που σας έστειλε αυτόν τον σύνδεσμο.",
    "Add to your ownCloud" : "Προσθήκη στο ownCloud σου",
    "Download" : "Λήψη",
    "Download %s" : "Λήψη %s",
    "Direct link" : "Άμεσος σύνδεσμος",
    "Federated Cloud Sharing" : "Διαμοιρασμός σε ομόσπονδα σύννεφα ",
    "Open documentation" : "Ανοιχτή τεκμηρίωση.",
    "Allow users on this server to send shares to other servers" : "Να επιτρέπεται σε χρήστες αυτού του διακομιστή να στέλνουν διαμοιρασμένους φακέλους σε άλλους διακομιστές",
    "Allow users on this server to receive shares from other servers" : "Να επιτρέπεται στους χρίστες του διακομιστή να λαμβάνουν διαμοιρασμένα αρχεία από άλλους διακομιστές",
    "Federated Cloud" : "Federated σύννεφο",
    "Your Federated Cloud ID:" : "Το ID σας στο Federated Cloud:",
    "Share it:" : "Μοιραστείτε το:",
    "Add to your website" : "Προσθήκη στην ιστοσελίδα σας",
    "Share with me via ownCloud" : "Διαμοιρασμός με εμένα μέσω του ",
    "HTML Code:" : "Κώδικας HTML:"
},
"nplurals=2; plural=(n != 1);");
